${ title }

<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="title_head"> <%block name="extra_meta"> ${ setup_margin_labels(title) }
${ header(complete_header, title, report.subtitle, notes) }

### ${ _("Quote") }

### ${ _("Details for quote number %s") % report.workorder.identifier }

${ _("Description") }: ${ report.workorder.description }

% if report.workorder.sellable:

${ _("Equipment") }: ${ report.workorder.sellable.description }

% endif

${ _("Estimated start") }: ${ format_date(report.workorder.estimated_start) }

${ _("Estimated finish") }: ${ format_date(report.workorder.estimated_finish) }

${ _("Estimated cost") }: ${ format_price(report.workorder.estimated_cost) if \ report.workorder.estimated_cost else '' }

### ${ _("Client details") }

${ _("Name") }: ${ report.workorder.client.person.name }

% if report.workorder.client.person.get_formatted_phone_number():

${ _("Phone") }: ${ report.workorder.client.person.get_formatted_phone_number() }

% endif % if report.workorder.client.person.get_formatted_mobile_number():

${ _("Cell Phone") }: ${ report.workorder.client.person.get_formatted_mobile_number() }

% endif % if report.workorder.client.person.get_address_string():

${ _("Address") }: ${ report.workorder.client.person.get_address_string() }

% endif
% if report.workorder.sale and report.workorder.order_items.count() > 0: <%include file="workorder-items.html" /> % endif
${ _("Details") }:

    ${ report.workorder.defect_detected or report.workorder.defect_reported }

${ _("Client signature") }
${ report.workorder.client.get_description() }
${ _("Responsible signature") }
% if report.workorder.quote_responsible: ${ report.workorder.quote_responsible.get_description() }
% endif